==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/06/06ede98f5fe2239cda3da6f9905e8a1f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/Event/ObjectCollectEvent.php */
class __TwigTemplate_575bacc9088c3b05aa7edc2641de9cc6 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\FormBundle\\Event;

use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\FormBundle\\Collection\\ObjectCollection;
use Mautic\\FormBundle\\Crate\\ObjectCrate;

final class ObjectCollectEvent extends CommonEvent
{
    private ObjectCollection \$objects;

    public function __construct()
    {
        \$this->objects = new ObjectCollection();
    }

    public function appendObject(ObjectCrate \$object): void
    {
        \$this->objects->append(\$object);
    }

    public function getObjects(): ObjectCollection
    {
        return \$this->objects;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/Event/ObjectCollectEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/Event/ObjectCollectEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/FormBundle/Event/ObjectCollectEvent.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/06/06ede98f5fe2239cda3da6f9905e8a1f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/Event/ObjectCollectEvent.php */
class __TwigTemplate_575bacc9088c3b05aa7edc2641de9cc6 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\FormBundle\\Event;

use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\FormBundle\\Collection\\ObjectCollection;
use Mautic\\FormBundle\\Crate\\ObjectCrate;

final class ObjectCollectEvent extends CommonEvent
{
    private ObjectCollection \$objects;

    public function __construct()
    {
        \$this->objects = new ObjectCollection();
    }

    public function appendObject(ObjectCrate \$object): void
    {
        \$this->objects->append(\$object);
    }

    public function getObjects(): ObjectCollection
    {
        return \$this->objects;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/Event/ObjectCollectEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/Event/ObjectCollectEvent.php", "/var/www/html/production-demo/app/bundles/FormBundle/Event/ObjectCollectEvent.php");
    }
}
